@@ -17,6 +17,11 @@ class Button(gtk.Button):
         self._set_icon(attrs.get('icon'))
 
     def _set_icon(self, stock):
+        image = self.get_image()
+        if not image and not stock:
+            return
+        elif image and image.get_stock()[0] == stock:
+            return
         if not stock:
             self.set_image(gtk.Image())
             return
@@ -28,6 +33,8 @@ class Button(gtk.Button):
     def state_set(self, record):
         if record:
             states = record.expr_eval(self.attrs.get('states', {}))
+            if record.group.readonly or record.readonly:
+                states['readonly'] = True
         else:
             states = {}
         if states.get('invisible', False):
