@@ -95,7 +95,10 @@ def eval_leaf(part, context, boolop=operator.and_):
             '=': 'in',
             '!=': 'not in',
             }[operand]
-    return OPERATORS[operand](context_field, value)
+    try:
+        return OPERATORS[operand](context_field, value)
+    except TypeError:
+        return False
 
 
 def inverse_leaf(domain):
