@@ -130,8 +130,6 @@ class Many2Many(WidgetInterface):
 
     def destroy(self):
         self.screen.destroy()
-        self.widget.destroy()
-        del self.widget
 
     def color_set(self, name):
         super(Many2Many, self).color_set(name)
@@ -146,6 +144,9 @@ class Many2Many(WidgetInterface):
         if not self.focus_out:
             return
         domain = self.field.domain_get(self.record)
+        add_remove = self.record.expr_eval(self.attrs.get('add_remove'))
+        if add_remove:
+            domain = [domain, add_remove]
         context = self.field.context_get(self.record)
         value = self.wid_text.get_text()
 
@@ -185,13 +186,26 @@ class Many2Many(WidgetInterface):
         self._sig_edit()
 
     def _sig_edit(self):
-        if self.screen.current_record:
-            def callback(result):
-                if result:
-                    self.screen.current_record.save()
-                else:
-                    self.screen.current_record.cancel()
-            WinForm(self.screen, callback)
+        if not self.screen.current_record:
+            return
+        # Create a new screen that is not linked to the parent otherwise on the
+        # save of the record will trigger the save of the parent
+        domain = self.field.domain_get(self.record)
+        add_remove = self.record.expr_eval(self.attrs.get('add_remove'))
+        if add_remove:
+            domain = [domain, add_remove]
+        screen = Screen(self.attrs['relation'], domain=domain,
+            view_ids=self.attrs.get('view_ids', '').split(','),
+            mode=['form'], views_preload=self.attrs.get('views', {}),
+            readonly=self.attrs.get('readonly', False))
+        screen.load([self.screen.current_record.id])
+
+        def callback(result):
+            if result:
+                screen.current_record.save()
+                # Force a reload on next display
+                self.screen.current_record.cancel()
+        WinForm(screen, callback)
 
     def _readonly_set(self, value):
         self._readonly = value
@@ -223,7 +237,7 @@ class Many2Many(WidgetInterface):
         if field is None:
             self.screen.new_group()
             self.screen.current_record = None
-            self.screen.parent = True
+            self.screen.parent = None
             self.screen.display()
             return False
         new_group = field.get_client(record)
@@ -233,7 +247,6 @@ class Many2Many(WidgetInterface):
         return True
 
     def set_value(self, record, field):
-        self.screen.save_tree_state()
         self.screen.current_view.set_value()
         return True
 
@@ -263,6 +276,9 @@ class Many2Many(WidgetInterface):
         elif index == 1:
             model = self.attrs['relation']
             domain = self.field.domain_get(self.record)
+            add_remove = self.record.expr_eval(self.attrs.get('add_remove'))
+            if add_remove:
+                domain = [domain, add_remove]
             context = self.field.context_get(self.record)
 
             screen = Screen(model, domain, context=context, mode=['form'])
