@@ -439,5 +439,5 @@ class WinExport(NoModal):
             return True
         except IOError, exception:
             common.warning(_("Operation failed!\nError message:\n%s")
-                % (exception.faultCode,), _('Error'))
+                % exception, _('Error'))
             return False
