@@ -20,22 +20,21 @@ class Window(object):
 
     @staticmethod
     def create(view_ids, model, res_id=False, domain=None,
-            context=None, mode=None, name=False, limit=None,
-            auto_refresh=False, search_value=None, icon=None):
+            context=None, order=None, mode=None, name=False, limit=None,
+            search_value=None, icon=None, tab_domain=None):
         from tryton.gui import Main
         if context is None:
             context = {}
 
         if model:
             from form import Form
-            win = Form(model, res_id, domain, mode=mode,
+            win = Form(model, res_id, domain, order=order, mode=mode,
                 view_ids=(view_ids or []), context=context, name=name,
-                limit=limit, auto_refresh=auto_refresh,
-                search_value=search_value)
+                limit=limit, search_value=search_value, tab_domain=tab_domain)
         else:
             from board import Board
             win = Board(model, view_ids and view_ids[0] or None,
-                context=context, name=name, auto_refresh=auto_refresh)
+                context=context, name=name)
         win.icon = icon
         Main.get_main().win_add(win, hide_current=Window.hide_current,
             allow_similar=Window.allow_similar)
