@@ -4,9 +4,8 @@ import httplib
 import logging
 import socket
 import os
-from threading import Semaphore
 from functools import partial
-from tryton.jsonrpc import ServerProxy, Fault
+from tryton.jsonrpc import ServerProxy, ServerPool, Fault
 from tryton.fingerprints import Fingerprints
 from tryton.config import get_config_dir
 from tryton.ipc import Server as IPCServer
@@ -24,8 +23,6 @@ CONTEXT = {}
 _VIEW_CACHE = {}
 _TOOLBAR_CACHE = {}
 _KEYWORD_CACHE = {}
-TIMEZONE = 'utc'
-_SEMAPHORE = Semaphore()
 _CA_CERTS = os.path.join(get_config_dir(), 'ca_certs')
 if not os.path.isfile(_CA_CERTS):
     _CA_CERTS = None
@@ -33,6 +30,8 @@ _FINGERPRINTS = Fingerprints()
 
 ServerProxy = partial(ServerProxy, fingerprints=_FINGERPRINTS,
     ca_certs=_CA_CERTS)
+ServerPool = partial(ServerPool, fingerprints=_FINGERPRINTS,
+    ca_certs=_CA_CERTS)
 
 
 def db_list(host, port):
@@ -44,7 +43,8 @@ def db_list(host, port):
         return result
     except Fault, exception:
         if exception.faultCode == 'AccessDenied':
-            raise
+            logging.getLogger(__name__).debug(-2)
+            return -2
         else:
             logging.getLogger(__name__).debug(repr(None))
             return None
@@ -68,7 +68,7 @@ def server_version(host, port):
         logging.getLogger(__name__).debug(repr(result))
         return result
     except (Fault, socket.error):
-        raise
+        return None
 
 
 def login(username, password, host, port, database):
@@ -78,17 +78,14 @@ def login(username, password, host, port, database):
     _TOOLBAR_CACHE = {}
     _KEYWORD_CACHE = {}
     try:
-        _SEMAPHORE.acquire()
-        try:
-            if CONNECTION is not None:
-                CONNECTION.close()
-            CONNECTION = ServerProxy(host, port, database)
-            logging.getLogger(__name__).info('common.db.login(%s, %s)' %
-                (username, 'x' * 10))
-            result = CONNECTION.common.db.login(username, password)
-            logging.getLogger(__name__).debug(repr(result))
-        finally:
-            _SEMAPHORE.release()
+        if CONNECTION is not None:
+            CONNECTION.close()
+        CONNECTION = ServerPool(host, port, database)
+        logging.getLogger(__name__).info('common.db.login(%s, %s)' %
+            (username, 'x' * 10))
+        with CONNECTION() as conn:
+            result = conn.common.db.login(username, password)
+        logging.getLogger(__name__).debug(repr(result))
     except socket.error:
         _USER = None
         _SESSION = ''
@@ -113,15 +110,13 @@ def logout():
     if IPCServer.instance:
         IPCServer.instance.stop()
     if CONNECTION is not None:
-        _SEMAPHORE.acquire()
         try:
             logging.getLogger(__name__).info('common.db.logout(%s, %s)' %
                 (_USER, _SESSION))
-            CONNECTION.common.db.logout(_USER, _SESSION)
+            with CONNECTION() as conn:
+                conn.common.db.logout(_USER, _SESSION)
         except (Fault, socket.error, httplib.CannotSendRequest):
             pass
-        finally:
-            _SEMAPHORE.release()
         CONNECTION.close()
         CONNECTION = None
     _USER = None
@@ -135,24 +130,6 @@ def logout():
     _KEYWORD_CACHE = {}
 
 
-def context_reload():
-    global CONTEXT, TIMEZONE, _HOST, _PORT
-    try:
-        context = execute('model', 'res.user', 'get_preferences', True, {})
-    except Fault:
-        return
-    CONTEXT = {}
-    for i in context:
-        value = context[i]
-        CONTEXT[i] = value
-        if i == 'timezone':
-            try:
-                connection = ServerProxy(_HOST, _PORT)
-                TIMEZONE = connection.common.server.timezone_get(None, None)
-            except Fault:
-                pass
-
-
 def _execute(blocking, *args):
     global CONNECTION, _USER, _SESSION
     if CONNECTION is None:
@@ -173,18 +150,14 @@ def _execute(blocking, *args):
             key = str(args)
             if key in _KEYWORD_CACHE:
                 return _KEYWORD_CACHE[key]
-    res = _SEMAPHORE.acquire(blocking)
-    if not res:
-        return
     try:
         name = '.'.join(args[:3])
         args = (_USER, _SESSION) + args[3:]
         logging.getLogger(__name__).info('%s%s' % (name, args))
-        result = getattr(CONNECTION, name)(*args)
+        with CONNECTION() as conn:
+            result = getattr(conn, name)(*args)
     except (httplib.CannotSendRequest, socket.error), exception:
         raise TrytonServerUnavailable(*exception.args)
-    finally:
-        _SEMAPHORE.release()
     if not CONFIG['dev']:
         if key and method == 'fields_view_get':
             _VIEW_CACHE[key] = result
